@@ -11,7 +11,13 @@
 #include <errno.h>
 #include <string.h>
 #include <inttypes.h>
+
+#ifdef linux
 #include <sys/sendfile.h>
+#elif defined(__APPLE__) || defined(__FreeBSD__)
+#include <sys/uio.h>
+#endif
+
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -25,7 +31,7 @@
 #include "http_parser.h"
 
 
-#define SERVER "meinheld/0.4.10"
+#define SERVER "meinheld/0.4.11"
 
 
 extern int max_content_length;      //max_content_length
